@@ -1,5 +1,5 @@
 -- deets: example.lua
--- Copyright (C) 2009, 2010, 2011  Clint Adams
+-- Copyright (C) 2009-2012  Clint Adams
 
 -- This program is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -12,8 +12,7 @@
 -- GNU General Public License for more details.
 
 -- You should have received a copy of the GNU General Public License
--- along with this program; if not, write to the Free Software
--- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
 --
 
 file.file({"/tmp/skrink/coccyx"}, {
@@ -62,3 +61,12 @@ file.directory({"/tmp/skrink"}, {
 file.file({"/tmp/regis"}, {
     ensure = "absent"
 })
+
+aug.root({"/files/etc/ssh/sshd_config/X11Forwarding"}, {
+    ensure = "unset"
+})
+
+aug.root({"/files/etc/ssh/ssh_config/Host/HashKnownHosts"}, {
+    ensure = "set",
+    value = "no"
+})
